@@ -3,7 +3,7 @@ import requests
 
 
 # suppresses invalid cert warnings, deprecated..., using verify=False
-requests.packages.urllib3.disable_warnings()
+requests.packages.urllib3.disable_warnings()  # pylint:disable=no-member
 
 
 class ValidateUrl:
@@ -16,11 +16,13 @@ class ValidateUrl:
 
     def validate(self):
         """Validate a HTTP respone is not a failure."""
-        headers = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.77 Safari/537.36"}
+        headers = {
+            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.77 Safari/537.36"
+        }
         if self.need_scheme:
-            resp = requests.get(f"http://{self.url}", headers=headers, verify=False)
+            resp = requests.get(f"http://{self.url}", headers=headers, verify=False)  # nosec
         else:
-            resp = requests.get(self.url, headers=headers, verify=False)
+            resp = requests.get(self.url, headers=headers, verify=False)  # nosec
         if not resp.ok:
             return False
         return True
